#[non_exhaustive]pub enum Error {
Overrun,
PeripheralError,
NeighborPinUnavailable,
NotReady,
InvalidFilterParameters,
InvalidConfig,
}Expand description
DFSDM error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Overrun
Overrun error: the hardware generated data faster than we could read it.
PeripheralError
Internal peripheral error.
Neighbor pin unavailable.
NotReady
No data available yet.
InvalidFilterParameters
Invalid filter parameters: FOSR/IOSR out of range, or the resulting filter gain exceeds the allowed ceiling for the input width.
InvalidConfig
Invalid configuration: a requested value (e.g. a CKOUT divider) is outside the achievable range.