pub struct DfsdmCommon<'d, T: Instance, P: PowerState> { /* private fields */ }Expand description
Holds references to the peripheral and the optional clock-output. Disables the RCC of the peripheral when dropped.
Implementations
Sourceimpl<'d, T> DfsdmCommon<'d, T, Disabled>where
T: Instance,
impl<'d, T> DfsdmCommon<'d, T, Disabled>where
T: Instance,
Sourcepub fn enable(self) -> DfsdmCommon<'d, T, Enabled>
pub fn enable(self) -> DfsdmCommon<'d, T, Enabled>
Enables the peripheral.
Sourceimpl<'d, T> DfsdmCommon<'d, T, Enabled>where
T: Instance,
impl<'d, T> DfsdmCommon<'d, T, Enabled>where
T: Instance,
Sourcepub fn disable(self) -> DfsdmCommon<'d, T, Disabled>
pub fn disable(self) -> DfsdmCommon<'d, T, Disabled>
Disables the peripheral.
Setting DFEN=0 stops any conversion in progress and resets the status registers (ISR) and the analog-watchdog status register (AWSR). The data registers (RDATAR/JDATAR) are not documented to be cleared.